@@ -1,7 +1,7 @@
 '''
 | Author:  Ezio416
 | Created: 2022-08-16
-| Updated: 2022-10-01
+| Updated: 2022-10-03
 
 - Functions for filesystem and path string manipulation
 
@@ -24,7 +24,7 @@ from zipfile import BadZipFile, ZipFile
 
 from py7zr import exceptions, SevenZipFile, unpack_7zarchive
 
-from .general import secmod_inverse, timestamp, unpack
+from .general import secmod, secmod_inverse, timestamp, unpack
 
 
 class File():
@@ -524,7 +524,7 @@ def joinpath(*parts) -> str:
     return '/'.join(parts)
 
 
-def listdir(path: str = '.', dirs: bool = True, files: bool = True, recursive: bool = False, search: str = '', case: bool = False, recency=0) -> tuple:
+def listdir(path: str = '.', dirs: bool = True, files: bool = True, recursive: bool = False, search: str = '', case: bool = False, recency=0, return_dict: bool = False, sort_dict: str = 'path'):
     '''
     - lists files/folders within a folder
     - allows for some filtering by filename and modify date
@@ -571,10 +571,34 @@ def listdir(path: str = '.', dirs: bool = True, files: bool = True, recursive: b
             - if multiple of the same type of value are passed in the string, i.e. "4h16h", only the first value is grabbed
         - default: 0 (include everything)
 
+    return_dict: bool
+        - whether to return a dictionary instead of a tuple
+        - dict contains details on each file with paths as keys and dicts of their details as values
+        - structured like so:
+            - {path: {'size': int, 'mtime': int, 'mage': str}}
+            - size: int
+                - bytes
+            - mtime: int
+                - modify time
+                - Unix timestamp
+            - mage: str
+                - how long ago the modify time was
+                - return is from :func:`py416.secmod`, i.e. '46d19h08m07s'
+        - default: False
+
+    sort_dict: str
+        - what to sort a returned dictionary by
+        - accepted values: path, size, mtime, mage
+        - always sorts in ascending order (small -> large)
+        - sorting by mage (modify age) is reverse to sorting by mtime (modify time)
+        - default: path
+
     Returns
     -------
-    tuple[str]
-        - absolute paths
+        - dict[str: dict[str: int, str: int, str: str]]
+            - absolute path, size, modify time, modify age
+        - tuple[str]
+            - absolute paths
     '''
     if not os.path.exists(path := getpath(path)):
         return ()
@@ -582,7 +606,10 @@ def listdir(path: str = '.', dirs: bool = True, files: bool = True, recursive: b
         raise TypeError(f'input must be a string; invalid: {search}')
     if (recency_type := type(recency)) not in (float, int, str):
         raise TypeError(f'input must be a number or string; invalid: {recency}')
+    if (sort_dict := str(sort_dict).lower()) not in ('path', 'size', 'mtime', 'mage'):
+        raise ValueError(f'invalid sort option: {sort_dict}')
     result = []
+    now = time()
     for child in os.listdir(path):
         child = joinpath(path, child)
         if os.path.isdir(child):
@@ -606,15 +633,29 @@ def listdir(path: str = '.', dirs: bool = True, files: bool = True, recursive: b
     if recency:
         tmp = []
         recency = secmod_inverse(recency) if recency_type is str else float(recency)
-        now = time()
         for fpath in result:
             if now - os.path.getmtime(fpath) < recency:
                 tmp.append(fpath)
-        return tuple(tmp)
+        result = tmp
+    if bool(return_dict):
+        mydict = {}
+        tmp = []
+        for fpath in result:
+            stat = os.stat(fpath)
+            tmp.append((fpath, stat.st_size, (mtime := stat.st_mtime), secmod(now - mtime)[0]))
+        if sort_dict == 'size':
+            tmp = sorted(tmp, key=lambda i: i[1])
+        elif sort_dict == 'mtime':
+            tmp = sorted(tmp, key=lambda i: i[2])
+        elif sort_dict == 'mage':
+            tmp = sorted(tmp, key=lambda i: i[2], reverse=True)
+        for file in tmp:
+            mydict[file[0]] = {'size': file[1], 'mtime': int(file[2]), 'mage': file[3]}
+        return mydict
     return tuple(result)
 
 
-def log(path: str, msg: str, ts: bool = True, ts_args: tuple = (1, 0, 1, 1, 1, 0)) -> None:
+def log(path: str, msg: str, ts: bool = True, ts_args: tuple = (1, 0, 1, 1, 1, 0), encoding: str = 'utf-8') -> None:
     '''
     - logs to file with current timestamp
     - creates file and its parent folder if nonexistent
@@ -634,13 +675,17 @@ def log(path: str, msg: str, ts: bool = True, ts_args: tuple = (1, 0, 1, 1, 1, 0
     ts_args: iterable
         - arguments to pass to :func:`py416.timestamp`
         - default return example: [2022-08-19 13:24:54 -06:00]
+
+    encoding: str
+        - character set
+        - default: utf-8
     '''
     if type(msg) is not str:
         raise ValueError(f'input must be a string; invalid: {msg}')
     if type(ts_args) not in (list, tuple):
         raise ValueError(f'input must be a list/tuple; invalid: {ts_args}')
     makedirs(parent(path := getpath(path)))
-    with open(path, 'a') as file:
+    with open(path, 'a', encoding=encoding) as file:
         file.write(f'{timestamp(*ts_args) + "  " if bool(ts) else ""}{msg}\n')
 
 
@@ -684,7 +729,7 @@ def makedirs(*dirs, ignore_errors: bool = True) -> tuple:
     return tuple(errored)
 
 
-def makefile(path: str, msg: str = '', overwrite: bool = False) -> str:
+def makefile(path: str, msg: str = '', overwrite: bool = False, encoding: str = 'utf-8') -> str:
     '''
     - creates a new file
     - wraps `open() <https://docs.python.org/3/library/functions.html#open>`_
@@ -702,6 +747,10 @@ def makefile(path: str, msg: str = '', overwrite: bool = False) -> str:
         - whether to overwrite a file if it already exists
         - default: False
 
+    encoding: str
+        - character set
+        - default: utf-8
+
     Returns
     -------
     str
@@ -716,7 +765,7 @@ def makefile(path: str, msg: str = '', overwrite: bool = False) -> str:
     if os.path.isdir(path):
         raise IsADirectoryError(f'destination already exists as a directory: {path}')
     makedirs(parent(path))
-    with open(path, 'a') as file:
+    with open(path, 'a', encoding=encoding) as file:
         file.write(msg)
     return path
 
